HostSystem

Enum HostSystem 

#[repr(u8)]
pub enum HostSystem {
Show 21 variants MsDos = 0, Amiga = 1, OpenVms = 2, Unix = 3, VmCms = 4, AtariSt = 5, Os2Hpfs = 6, Macintosh = 7, ZSystem = 8, CpM = 9, WindowsNtfs = 10, Mvs = 11, Vse = 12, AcornRisc = 13, Vfat = 14, AlternateMvs = 15, BeOs = 16, Tandem = 17, Os400 = 18, Osx = 19, Unknown(u8),
}
System on which an archive was created, as encoded into a version u16.

See APPNOTE, section 4.4.2.2

Variants



MsDos = 0

MS-DOS and OS/2 (FAT / VFAT / FAT32 file systems)



Amiga = 1

Amiga



OpenVms = 2

OpenVMS



Unix = 3

UNIX



VmCms = 4

VM/CMS



AtariSt = 5

Atari ST



Os2Hpfs = 6

OS/2 H.P.F.S



Macintosh = 7

Macintosh (see Osx)



ZSystem = 8

Z-System



CpM = 9

CP/M



WindowsNtfs = 10

Windows NTFS



Mvs = 11

MVS (OS/390 - Z/OS)



Vse = 12

VSE



AcornRisc = 13

Acorn Risc



Vfat = 14

VFAT



AlternateMvs = 15

alternate MVS



BeOs = 16

BeOS



Tandem = 17

Tandem



Os400 = 18

OS/400



Osx = 19

OS X (Darwin)



Unknown(u8)

Unknown host system

Values 20 through 255 are currently unused, as of APPNOTE.TXT 6.3.10

Implementations

Source

impl HostSystem

pub fn to_owned(&self) -> HostSystem

Copy the structure and clone the original values.

This is always a deep copy.

Source

impl HostSystem

pub fn into_owned(self) -> HostSystem

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.