Mode

Struct Mode 

pub struct Mode(pub u32);
Mode represents a file’s mode and permission bits. The bits have the same definition on all systems, but not all bits apply to all systems.

It is modelled after Go’s os.FileMode.

Tuple Fields

0: u32

Implementations

Source

impl Mode

pub const DIR: Self

d: is a directory

pub const APPEND: Self

a: append-only

pub const EXCLUSIVE: Self

l: exclusive use

pub const TEMPORARY: Self

T: temporary file; Plan 9 only

L: symbolic link

pub const DEVICE: Self

D: device file

pub const NAMED_PIPE: Self

p: named pipe (FIFO)

pub const SOCKET: Self

S: Unix domain socket

pub const SETUID: Self

u: setuid

pub const SETGID: Self

g: setgid

pub const CHAR_DEVICE: Self

c: Unix character device, when DEVICE is set

pub const STICKY: Self

t: sticky

pub const IRREGULAR: Self

?: non-regular file; nothing else is known

Source

impl Mode

pub fn has(&self, rhs: Self) -> bool

Check if the mode has the given bits set.